@@ -104,7 +104,7 @@ class TableWidget(QWidget):
 
 
 def show(viewer: Any, array: np.ndarray, metadata: czimd.CziMetadata,
-         dim_order: dict,
+         dim_string: str,
          blending: str = "additive",
          contrast: str = "calc",
          gamma: float = 0.85,
@@ -117,7 +117,7 @@ def show(viewer: Any, array: np.ndarray, metadata: czimd.CziMetadata,
     :param viewer: Napari viewer object
     :param array: multi-dimensional array containing the pixel data
     :param metadata: CziMetadata class
-    :param dim_order: Dictionary with the dimension order.
+    :param dim_string: the dimension string for the array to be shown
     :param blending: blending mode for viewer
     :param contrast: method to be used to calculate an appropriate display scaling.
     - "calc" : real min & max calculation (might be slow) be calculated (slow)
@@ -129,6 +129,8 @@ def show(viewer: Any, array: np.ndarray, metadata: czimd.CziMetadata,
     :return:
     """
 
+    dim_order, dim_index, dim_valid = czimd.CziMetadata.get_dimorder(dim_string)
+
     # check if contrast mode
     if contrast not in ["calc", "napari_auto", "from_czi"]:
         print(contrast, "is not valid contrast method. Use napari_auto instead.")
@@ -141,7 +143,12 @@ def show(viewer: Any, array: np.ndarray, metadata: czimd.CziMetadata,
     scalefactors = [1.0] * len(array.shape)
 
     # modify the tuple for the scales for napari
-    scalefactors[dim_order["Z"]] = metadata.scale.ratio["zx"]
+
+    # the "strange factor" is added due to an open (rounding) bug on the Napari side:
+    # https://github.com/napari/napari/issues/4861
+    # https://forum.image.sc/t/image-layer-in-napari-showing-the-wrong-dimension-size-one-plane-is-missing/69939/12
+
+    scalefactors[dim_order["Z"]] = metadata.scale.ratio["zx"] * 1.0000001
 
     # add Qt widget for metadata
     if add_mdtable:
@@ -163,8 +170,6 @@ def show(viewer: Any, array: np.ndarray, metadata: czimd.CziMetadata,
     else:
         sizeC = metadata.image.SizeC
 
-    #import webcolors
-
     # loop over all channels and add them as layers
     for ch in range(sizeC):
 
@@ -253,9 +258,11 @@ def show(viewer: Any, array: np.ndarray, metadata: czimd.CziMetadata,
         viewer.dims.axis_labels = sliderlabels
 
     # workaround because of: https://forum.image.sc/t/napari-3d-view-shows-flat-z-stack/62744/9?u=sebi06
-    od = list(viewer.dims.order)
-    od[dim_order["C"]], od[dim_order["Z"]] = od[dim_order["Z"]], od[dim_order["C"]]
-    viewer.dims.order = tuple(od)
+    if dim_string == "STZCYX" or dim_string == "TZCYX":
+
+        od = list(viewer.dims.order)
+        od[dim_order["C"]], od[dim_order["Z"]] = od[dim_order["Z"]], od[dim_order["C"]]
+        viewer.dims.order = tuple(od)
 
     return napari_layers
 
